;; Generated package description from mode: lisp-data; .el  -*- denote-sequenceno-byte-compile: t -*-
(define-package "denote-sequence" "0.0.0.1.0.20250401.84519" "Sequence notes or Folgezettel with Denote" '((emacs "28.1") (denote "3.1.0")) :commit "c41c3dea4d02811ab285abd139451b5850b4320c" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-sequence")
